<template>
    <div class="system-gas-container">
        <el-card shadow="hover">
            <div class="system-menu-search mb15">
                <el-form :inline="true" >
                    <el-form-item label="气体名称：">
                        <el-input  v-model="state.tableData.listQuery.searchParams.areaName"  placeholder="区域名称" ></el-input>
                    </el-form-item>
                    <el-button size="default" type="primary" class="ml10">
                        <el-icon>
                            <ele-Search />
                        </el-icon>
                        查询
                    </el-button>
                    <el-button size="default" class="ml10" @click="reset()">
                        <el-icon>
                            <RefreshLeft />
                        </el-icon>
                        重置
                    </el-button>
                </el-form>
            </div>
            <el-button size="default" class="mb10" type="success" @click="openDialog('新增',{})">
                <el-icon>
                    <ele-FolderAdd />
                </el-icon>
                新增区域
            </el-button>

            <el-table :data="state.tableData.data" style="width: 100%">
                <el-table-column align="center" prop="areaName" label="区域名称"/>
                <el-table-column align="center"  label="区域经纬度">
                    <template #default="scope">
                        <div v-for="(item, index) in scope.row.areaLngLat" :key="index">
                            [{{item.lng}},{{item.lat}}]
                        </div>
                    </template>
                </el-table-column>
                <el-table-column label="操作" show-overflow-tooltip width="140">
                    <template #default="scope">
                        <el-button size="small" text type="primary" @click="openDialog('查看', scope.row)">查看</el-button>
                        <el-button size="small" text type="primary" @click="openDialog('修改', scope.row)">修改</el-button>
                        <el-button size="small" text type="danger" @click="del(scope.row)">删除</el-button>
                    </template>
                </el-table-column>
            </el-table>
            <br />
            <el-pagination
                @size-change="onHandleSizeChange"
                @current-change="onHandleCurrentChange"
                class="page-position"
                :pager-count="5"
                :page-sizes="[10, 20, 30]"
                v-model:current-page="state.tableData.listQuery.pageIndex"
                background
                v-model:page-size="state.tableData.listQuery.pageSize"
                layout="total, sizes, prev, pager, next, jumper"
                :total="state.tableData.total">
            </el-pagination>
            <br />
            <br />
        </el-card>
        <area-dialog ref="areaRef" @getAreaData="initAreaData"></area-dialog>
    </div>
</template>

<script setup lang="ts">
import {reactive, ref} from "vue";
import { TableDataState } from "/@/types/areaManage";
import areaDialog from "./component/areaDialog.vue";
import {ElMessage, ElMessageBox} from "element-plus";

const areaRef = ref();
const state = reactive<TableDataState>({
    tableData: {
        data: [
            // {
            //     id: 'xxx',
            //     areaName: 'xxx',
            //     areaLngLat: [
            //         {
            //             lng: '11',
            //             lat:'22'
            //         },
            //         {
            //             lng: '11',
            //             lat:'22'
            //         }
            //     ],
            //     areaColor: "#ffffff"
            // }
        ],
        total: 0,
        loading: false,
        listQuery: {
            pageIndex: 1,
            pageSize: 10,
            searchParams:{
                areaName:''
            }
        }
    }
});

const initAreaData = () => {
    console.log("数据列表")
};
const onHandleSizeChange = (val: number) => {
    state.tableData.listQuery.pageSize = val;
    initAreaData();
};
// 分页改变
const onHandleCurrentChange = (val: number) => {
    state.tableData.listQuery.pageIndex = val;
    initAreaData();
};
const openDialog = (type: string, value: any) => {
    areaRef.value.openDialog(type, value);
};
const del = (val: any) => {
    ElMessageBox.confirm(
        '确定删除此条数据？',
        '提示',
        {
            confirmButtonText: '确定',
            cancelButtonText: '取消',
            type: 'warning',
        }
    )
        .then(() => {
            ElMessage({
                type: 'success',
                message: '删除成功',
            })
        })
};
const reset = () => {
    state.tableData.listQuery.searchParams.areaName = '';
}
</script>
<style scoped lang="scss">

</style>